//
//	aegis - project change supervisor
//	Copyright (C) 2002-2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate skips
//

#include <libaegis/input.h>


void
input_ty::skip(size_t size)
{
    while (size > 0)
    {
	size_t nbytes = size;
	if (nbytes > sizeof(buffer))
	    nbytes = sizeof(buffer);
	char throw_me_away[1024];
	read_strictest(throw_me_away, nbytes);
	size -= nbytes;
    }
}
